@@ -1129,9 +1129,19 @@ static bool const statically_linked = true;
 #endif
 
       // cwbfd::
-      bfile_ct* load_object_file(char const* name, void* l_addr)
+      bfile_ct* load_object_file(char const* name, void* l_addr, bool initialized = false)
       {
+	static bool WST_initialized = false;
 	LIBCWD_TSD_DECLARATION;
+	// If dlopen is called as very first function (instead of malloc), we get here
+	// as first function inside libcwd. In that case, initialize libcwd first.
+	if (!WST_initialized)
+	{
+	  if (initialized)
+	    WST_initialized = true;
+	  else if (!ST_init(LIBCWD_TSD))
+	    return NULL;
+	}
 #if CWDEBUG_DEBUGM
 	LIBCWD_ASSERT( !__libcwd_tsd.internal );
 #endif
@@ -1243,15 +1253,15 @@ static bool const statically_linked = true;
 #if CWDEBUG_DEBUG && CWDEBUG_ALLOC
 	LIBCWD_ASSERT( !__libcwd_tsd.internal );
 #endif
+#if CWDEBUG_ALLOC
+	// Initialize the malloc library if not done yet.
+	init_debugmalloc();
+#endif
 
 	// ****************************************************************************
 	// Start INTERNAL!
 	set_alloc_checking_off(LIBCWD_TSD);
 
-#if CWDEBUG_ALLOC
-	// Initialize the malloc library if not done yet.
-	init_debugmalloc();
-#endif
         new (fake_ST_shared_libs) ST_shared_libs_vector_ct;
 
 	libcwd::debug_ct::OnOffState state;
@@ -1287,7 +1297,7 @@ static bool const statically_linked = true;
 
 	  // Load executable
 	  BFD_INITIALIZE_LOCK;
-	  load_object_file(fullpath.data(), executable_l_addr);
+	  load_object_file(fullpath.data(), executable_l_addr, true);
 
 	  if (!statically_linked)
 	  {
