@@ -1,4 +1,4 @@
-// $Header: /cvsroot/libcwd/libcwd/type_info.cc,v 1.24 2004/08/13 00:59:02 libcw Exp $
+// $Header$
 //
 // Copyright (C) 2000 - 2004, by
 // 
@@ -43,7 +43,7 @@ namespace _private_ {
     size_t len = strlen(encap_mangled_name + 25) - 1;		// Strip "22libcwd_type_info_exactI" from the beginning and "E" from the end.
 #endif
     set_alloc_checking_off(LIBCWD_TSD);
-    char* exact_name = new char[len + 1];			// Leaks memory.
+    char* exact_name = new char[len + 1];			// LEAK58
     set_alloc_checking_on(LIBCWD_TSD);
 #if __GXX_ABI_VERSION == 0
     strncpy(exact_name, encap_mangled_name + 27, len);
@@ -69,7 +69,7 @@ namespace _private_ {
     {
       internal_string out;
       demangle_type(mangled_name, out);
-      label = strcpy(new char[out.size() + 1], out.c_str());	// Leaks memory.
+      label = strcpy(new char[out.size() + 1], out.c_str());	// LEAK44
     }
     set_alloc_checking_on(LIBCWD_TSD);
     return label;
