@@ -1,4 +1,4 @@
-// $Header: /cvsroot/libcwd/libcwd/utils/exec_prog.cc,v 1.36 2004/08/31 19:01:53 libcw Exp $
+// $Header$
 //
 // Copyright (C) 2000 - 2004, by
 //
@@ -23,6 +23,7 @@
 #include <signal.h>		// Needed for kill(2) and SIGKILL
 #include "exec_prog.h"
 #include "cwd_debug.h"
+#include "environment.h"
 #include <libcwd/buf2str.h>
 #include <libcwd/cwprint.h>
 #include <libcwd/private_assert.h>
@@ -34,14 +35,6 @@
 namespace libcwd {
 
 namespace {
-  class environment_ct {
-  private:
-    char const* const* __envp;
-  public:
-    environment_ct(char const* const envp[]) : __envp(envp) { }
-    void print_on(std::ostream& os) const;
-  };
-
   class argv_ct {
   private:
     char const* const* __argv;
@@ -437,19 +430,6 @@ namespace {		// Implementation of local functions
     os << "NULL ]";
   }
 
-  // {anonymous}::
-  void environment_ct::print_on(std::ostream& os) const
-  {
-    os << "[ ";
-    char const* const* p = __envp;
-    while(*p)
-    {
-      os << '"' << buf2str(*p, strlen(*p)) << "\", ";
-      ++p;
-    }
-    os << "NULL ]";
-  }
-
 } // namespace {anonymous}
 
 } // namespace libcwd
